@@ -1,15 +1,30 @@
 # -*- coding: utf-8 -*-
+#
+# Copyright (C) 2020 Dremio
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
 """Top-level package for Python API and CLI for Nessie."""
 import os
 
 import confuse
 
+from .client import NessieClient
 from .conf import build_config
-from .nessie_client import NessieClient
 
 __author__ = """Project Nessie"""
 __email__ = "nessie-release-builder@dremio.com"
-__version__ = "0.7.0"
+__version__ = "0.15.0"
 
 
 def get_config(config_dir: str = None, args: dict = None) -> confuse.Configuration:
@@ -29,7 +44,7 @@ def init(config_dir: str = None, config_dict: dict = None) -> NessieClient:
     >>> client = init('/my/config/dir')
     """
     if config_dict is None:
-        config_dict = dict()
+        config_dict = {}
     config = get_config(config_dir, args=config_dict)
     return _connect(config)
 
